# Contributing to Mailchain

We :heart: your input! We want to make contributing to this project as easy and transparent as possible, whether it's:

- Reporting a bug
- Discussing the current state of the code
- Submitting a fix
- Proposing new features
- Becoming a maintainer

## Reading

There are 2 important documents to read to understand how we are building Mailchain.

1. We use [Tenets](https://github.com/mailchain/mailchain-specification/blob/master/mailchain_tenets.md) to guide the way we make decisions.
2. Please read the [spec](https://github.com/mailchain/mailchain-specification) to understand Mailchain requirements, important if you are making changes to the way Mailchain works.

## We Develop with Github

We use Github to host code, to track issues and feature requests, as well as accept pull requests. All changes should be related to issues.

## We Use [Github Flow](https://guides.github.com/introduction/flow/index.html)

All code changes happen through pull requests, they are the best way to propose changes to the codebase (we use [Github Flow](https://guides.github.com/introduction/flow/index.html)). We actively welcome your pull requests:

1. Fork the repository and create your branch from `master`.
2. Add tests to cover the code you have added.
3. Update documentation to explain any changes to the API.
4. Ensure the test suite passes.
5. Make sure your code lints.
6. Create that pull request!

## Any contributions you make will be under the Apache 2.0 Software License

In short, when you submit code changes, your submissions are understood to be under the same [Apache License 2.0](http://choosealicense.com/licenses/apache-2.0/) that covers the project. Feel free to contact the maintainers if that's a concern.

## Report bugs using Github's [issues](https://github.com/mailchain/mailchain/issues)

We use GitHub issues to track public bugs. Report a bug by [opening a new issue](https://github.com/mailchain/mailchain/issues/new/choose); it's that easy!

## Write bug reports with detail

Use this [template](https://github.com/mailchain/mailchain/issues/new?assignees=&labels=bug&template=bug_report.md&title=) and include any details, steps to reproduce, background, and sample code.

**Great Bug Reports** tend to have:

- A quick summary and/or background
- Steps to reproduce
  - Be specific!
  - Give sample code if you can.
- What you expected would happen
- What actually happens.
- Notes (possibly including why you think this might be happening, or stuff you tried that didn't work).

People *love* thorough bug reports. I'm not even kidding.

## Use Consistent Coding Practices

To ensure consistency we use https://pre-commit.com/

1. Install instructions https://pre-commit.com/#install
1. Run `pre-commit install` to install all pre-commit hooks
1. Develop and commit code, on commit the hook will run to validate the code.

## License

By contributing, you agree that your contributions will be licensed under its Apache 2.0 License.

## References

This document was adapted from the open-source contribution guidelines for [Facebook's Draft](https://github.com/facebook/draft-js/blob/a9316a723f9e918afde44dea68b5f9f39b7d9b00/CONTRIBUTING.md)
